@@ -22,23 +22,22 @@
 #define JOURNALHANDLER_H
 
 #include "incidencehandler.h"
-#include <kcal/journal.h>
+#include <kcalcore/journal.h>
 
 /**
 	@author Andras Mantia <amantia@kde.org>
 */
 class JournalHandler : public IncidenceHandler {
 public:
-  JournalHandler();
+  JournalHandler( const Akonadi::Collection &imapCollection );
   virtual ~JournalHandler();
 
   virtual QStringList contentMimeTypes();
   virtual QString iconName() const;
 
 private:
-  virtual QByteArray incidenceToXml(KCal::Incidence *incidence);
-  virtual KCal::Incidence* incidenceFromKolab(const KMime::Message::Ptr &data);
-  KCal::Journal *journalFromKolab(const KMime::Message::Ptr &data);
+  virtual QByteArray incidenceToXml( const KCalCore::Incidence::Ptr &incidence);
+  virtual KCalCore::Incidence::Ptr incidenceFromKolab(const KMime::Message::Ptr &data);
 };
 
 #endif
